==> mango-context-1.0.9-20210915.034828-37-sources.jar: cn/tuia/mango/context/service/impl/BaseMybatisInternalServiceImpl.java <==
package cn.tuia.mango.context.service.impl;

import cn.tuia.mango.context.mapper.BaseMybatisInternalMapper;
import cn.tuia.mango.context.service.BaseMybatisInternalService;
import cn.tuia.mango.core.domain.BaseDomain;
import cn.tuia.mango.core.domain.page.PageParam;
import cn.tuia.mango.core.domain.page.PageData;
import cn.tuia.mango.core.util.TypeKit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;
import org.springframework.util.CollectionUtils;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.List;

/**
 * @author lijicong
 * @since 2020-03-19
 */
public class BaseMybatisInternalServiceImpl<M extends BaseMybatisInternalMapper<T>, T extends BaseDomain> //
        extends BaseServiceImpl //
        implements BaseMybatisInternalService<M, T> {

    @Autowired
    protected M mapper;
    private Type[] typeArray;
    private Class<T> domainClazz;

    public M getMapper() {
        return mapper;
    }

    // 泛型处理
    @SuppressWarnings("unchecked")
    protected Type[] getTypeArray() {
        if (typeArray == null) {
            typeArray = ((ParameterizedType) getClass().getGenericSuperclass()).getActualTypeArguments();
        }
        return TypeKit.getActualTypes(getClass());
    }

    @SuppressWarnings("unchecked")
    protected Class<T> getDomainClazz() {
        if (domainClazz == null) {
            domainClazz = (Class<T>) getTypeArray()[1];
        }
        return domainClazz;
    }

    protected T query() {
        return newDomainIfNull(null);
    }

    protected T newDomain() {
        return newDomainIfNull(null);
    }

    protected T newDomainIfNull(T model) {
        if (model == null) {
            try {
                model = getDomainClazz().newInstance();
            } catch (InstantiationException | IllegalAccessException e) {
            }
        }
        return model;
    }

    @Override
    public int deleteByPrimaryKey(Long id) {
        Assert.notNull(id, "id must not be null");
        if (log.isDebugEnabled()) {
            log.debug("物理删除对象 id={}", id);
        }
        return getMapper().deleteByPrimaryKey(id);
    }

    @Override
    public int insert(T domain) {
        Assert.notNull(domain, "domain must not be null");
        return getMapper().insert(domain);
    }

    @Override
    public int insertSelective(T domain) {
        Assert.notNull(domain, "domain must not be null");
        return getMapper().insertSelective(domain);
    }

    @Override
    public int insertBatch(List<T> list) {
        Assert.notEmpty(list, "list must not be empty");
        Assert.isTrue(list.size() <= 500, "list must less than 500");
        return getMapper().insertBatch(list);
    }

    @Override
    public T getById(Long id) {
        Assert.notNull(id, "id must not be null");
        return getMapper().selectByPrimaryKey(id);
    }

    @Override
    public int updateByPrimaryKeySelective(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        return getMapper().updateByPrimaryKeySelective(domain);
    }

    @Override
    public int updateByPrimaryKey(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        return getMapper().updateByPrimaryKey(domain);
    }

    @Override
    public int save(T domain) {
        Assert.notNull(domain, "domain must not be null");
        if (domain.getId() == null) {
            return getMapper().insertSelective(domain);
        }
        return getMapper().updateByPrimaryKeySelective(domain);
    }

    @Override
    public List<T> list() {
        T query = newDomain();
        query.setCurrentAndSize(1, 500);
        return getMapper().selectList(query);
    }

    @Override
    public List<T> list(T query) {
        Assert.notNull(query, "query must not be null");
        return getMapper().selectList(query);
    }

    @Override
    public List<T> list(T query, int size) {
        Assert.notNull(query, "query must not be null");
        query.setCurrentAndSize(1, size);
        return getMapper().selectList(query);
    }

    @Override
    public T getOne(T query) {
        Assert.notNull(query, "query must not be null");
        query.setCurrentAndSize(1, 1);
        List<T> result = getMapper().selectList(query);
        if (CollectionUtils.isEmpty(result)) {
            return null;
        }
        return result.get(0);
    }

    @Override
    public long count(T query) {
        Assert.notNull(query, "query must not be null");
        return getMapper().selectCount(query);
    }

    @Override
    public PageData<T> page(T query, int page, int size) {
        Assert.notNull(query, "query must not be null");
        query.setCurrentAndSize(page, size);
        return doFindPage(query);
    }

    @Override
    public PageData<T> page(T query) {
        Assert.notNull(query, "query must not be null");
        if (query.getPageParam() == null) {
            query.setPageParam(new PageParam());
        }
        return doFindPage(query);
    }

    protected PageData<T> doFindPage(T query) {
        PageData<T> pageResult = new PageData<>();
        long total = getMapper().selectCount(query);
        if (total > 0) {
            List<T> records = getMapper().selectList(query);
            pageResult.setRecords(records);
        }
        pageResult.setTotal(total);
        return pageResult;
    }

    @Override
    public T add(T domain) {
        Assert.notNull(domain, "domain must not be null");
        getMapper().insertSelective(domain);
        return domain;
    }

    @Override
    public T edit(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        getMapper().updateByPrimaryKeySelective(domain);
        return domain;
    }

    @Override
    public int deleteLogically(Long id) {
        Assert.notNull(id, "id must not be null");
        T domain = newDomain();
        domain.setId(id);
        domain.setIsDeleted(1);
        return getMapper().updateByPrimaryKeySelective(domain);
    }

}

==> mango-context-1.0.14-sources.jar: cn/tuia/mango/context/service/impl/BaseMybatisInternalServiceImpl.java <==
package cn.tuia.mango.context.service.impl;

import cn.tuia.mango.context.mapper.BaseMybatisInternalMapper;
import cn.tuia.mango.context.service.BaseMybatisInternalService;
import cn.tuia.mango.core.domain.BaseDomain;
import cn.tuia.mango.core.domain.page.PageParam;
import cn.tuia.mango.core.domain.page.PageData;
import cn.tuia.mango.core.util.TypeKit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.Assert;
import org.springframework.util.CollectionUtils;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 基础Service实现
 * @author lijicong
 * @since 2020-03-19
 */
public class BaseMybatisInternalServiceImpl<M extends BaseMybatisInternalMapper<T>, T extends BaseDomain> //
        extends BaseServiceImpl //
        implements BaseMybatisInternalService<M, T> {

    protected M mapper;
    private Type[] typeArray;
    private Class<T> domainClazz;

    @Autowired
    public void setMapper(M mapper) {
        this.mapper = mapper;
    }

    public M getMapper() {
        return mapper;
    }

    // 泛型处理
    @SuppressWarnings("unchecked")
    protected Type[] getTypeArray() {
        if (typeArray == null) {
            typeArray = ((ParameterizedType) getClass().getGenericSuperclass()).getActualTypeArguments();
        }
        return TypeKit.getActualTypes(getClass());
    }

    @SuppressWarnings("unchecked")
    protected Class<T> getDomainClazz() {
        if (domainClazz == null) {
            domainClazz = (Class<T>) getTypeArray()[1];
        }
        return domainClazz;
    }

    protected T query() {
        return newDomainIfNull(null);
    }

    protected T newDomain() {
        return newDomainIfNull(null);
    }

    protected T newDomainIfNull(T model) {
        if (model == null) {
            try {
                model = getDomainClazz().newInstance();
            } catch (InstantiationException | IllegalAccessException e) {

            }
        }
        return model;
    }

    @Override
    public int deleteByPrimaryKey(Long id) {
        Assert.notNull(id, "id must not be null");
        if (log.isDebugEnabled()) {
            log.debug("物理删除对象 id={}", id);
        }
        return getMapper().deleteByPrimaryKey(id);
    }

    @Override
    public int insert(T domain) {
        Assert.notNull(domain, "domain must not be null");
        return getMapper().insert(domain);
    }

    @Override
    public int insertSelective(T domain) {
        Assert.notNull(domain, "domain must not be null");
        return getMapper().insertSelective(domain);
    }

    @Override
    public int insertBatch(List<T> list) {
        Assert.notEmpty(list, "list must not be empty");
        Assert.isTrue(list.size() <= 500, "list must less than 500");
        return getMapper().insertBatch(list);
    }

    @Override
    public T getById(Long id) {
        Assert.notNull(id, "id must not be null");
        return getMapper().selectByPrimaryKey(id);
    }

    @Override
    public int updateByPrimaryKeySelective(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        return getMapper().updateByPrimaryKeySelective(domain);
    }

    @Override
    public int updateByPrimaryKey(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        return getMapper().updateByPrimaryKey(domain);
    }

    @Override
    public int save(T domain) {
        Assert.notNull(domain, "domain must not be null");
        if (domain.getId() == null) {
            return getMapper().insertSelective(domain);
        }
        return getMapper().updateByPrimaryKeySelective(domain);
    }

    @Override
    public List<T> list() {
        T query = newDomain();
        query.setCurrentAndSize(1, 500);
        return getMapper().selectList(query);
    }

    @Override
    public List<T> list(T query) {
        query = newDomainIfNull(query);
        return getMapper().selectList(query);
    }

    @Override
    public List<T> list(T query, int size) {
        query = newDomainIfNull(query);
        query.setCurrentAndSize(1, size);
        return getMapper().selectList(query);
    }

    @Override
    public List<T> listByIds(List<Long> ids) {
        T query = newDomain();
        query.setIds(ids);
        return getMapper().selectList(query);
    }

    @Override
    public Map<Long, T> map(T query) {
        query = newDomainIfNull(query);
        List<T> list = getMapper().selectList(query);
        if (CollectionUtils.isEmpty(list)) {
            return Collections.emptyMap();
        }
        return list.stream().collect(Collectors.toMap(BaseDomain::getId, e -> e, (o, n) -> n));
    }

    @Override
    public Map<Long, T> mapByIds(List<Long> ids) {
        T query = newDomain();
        query.setIds(ids);
        List<T> list = getMapper().selectList(query);
        if (CollectionUtils.isEmpty(list)) {
            return Collections.emptyMap();
        }
        return list.stream().collect(Collectors.toMap(BaseDomain::getId, e -> e, (o, n) -> n));
    }

    @Override
    public T getOne(T query) {
        query = newDomainIfNull(query);
        query.setCurrentAndSize(1, 1);
        List<T> result = getMapper().selectList(query);
        if (CollectionUtils.isEmpty(result)) {
            return null;
        }
        return result.get(0);
    }

    @Override
    public long count(T query) {
        query = newDomainIfNull(query);
        return getMapper().selectCount(query);
    }

    @Override
    public PageData<T> page(T query, int page, int size) {
        query = newDomainIfNull(query);
        query.setCurrentAndSize(page, size);
        return doFindPage(query);
    }

    @Override
    public PageData<T> page(T query) {
        query = newDomainIfNull(query);
        if (query.getPageParam() == null) {
            query.setPageParam(new PageParam());
        }
        return doFindPage(query);
    }

    protected PageData<T> doFindPage(T query) {
        PageData<T> pageResult = new PageData<>();
        long total = getMapper().selectCount(query);
        if (total > 0) {
            List<T> records = getMapper().selectList(query);
            pageResult.setRecords(records);
        }
        pageResult.setTotal(total);
        return pageResult;
    }

    @Override
    public T add(T domain) {
        Assert.notNull(domain, "domain must not be null");
        getMapper().insertSelective(domain);
        return domain;
    }

    @Override
    public T edit(T domain) {
        Assert.notNull(domain, "domain must not be null");
        Assert.notNull(domain.getId(), "domain.id must not be null");
        getMapper().updateByPrimaryKeySelective(domain);
        return domain;
    }

    @Override
    public int deleteLogically(Long id) {
        Assert.notNull(id, "id must not be null");
        T domain = newDomain();
        domain.setId(id);
        domain.setIsDeleted(1);
        return getMapper().updateByPrimaryKeySelective(domain);
    }

}
